"""Const for LIFX."""

DOMAIN = "lifx"
